package com.example.ficherosmemoriainterna;

import androidx.appcompat.app.AppCompatActivity;

import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.example.ficherosmemoriainterna.databinding.ActivityMainBinding;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {
    private ActivityMainBinding binding;
    public static final String FICHERO = "fichero.txt";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        binding = ActivityMainBinding.inflate(getLayoutInflater());
        View view = binding.getRoot();
        setContentView(view);

        binding.botonEscribir.setOnClickListener(this);
        binding.botonLeer.setOnClickListener(this);
        binding.botonLeerRaw.setOnClickListener(this);

        File directory = getApplicationContext().getFilesDir();
        mostrarMensaje(directory.toString());

    }

    @Override
    public void onClick(View view) {
        // Si pulsamos en el botón escribir
        if (view == binding.botonEscribir)
            escribirFichero();
        // Si pulsamos en el botón leer
        else if (view == binding.botonLeer)
            leerFichero();
        // Si pulsamos en el botón leer Raw
        else if (view == binding.botonLeerRaw)
            leerFicheroRaw();
    }

    private void escribirFichero(){
        try
        {
            String cadena = binding.cuadroTexto.getText().toString();

            OutputStreamWriter fout= new OutputStreamWriter(
                    openFileOutput(FICHERO, Context.MODE_PRIVATE));

            fout.write(cadena);
            fout.close();
        }
        catch (IOException e)
        {
            String texto = "Error al escribir fichero en la memoria interna: " + e.getMessage();
            Log.e("Ficheros", texto);
            mostrarMensaje(texto);
        }
    }

    private void leerFichero(){
        try
        {
            String linea="";
            String cadena="";
            BufferedReader fin = new BufferedReader(
                    new InputStreamReader(openFileInput(FICHERO)));

            while((linea = fin.readLine())!=null){
                cadena += linea + "\n";
            }
            fin.close();

            binding.cuadroTexto.setText(cadena);
        }
        catch (IOException e)
        {
            String texto = "Error al leer fichero de la memoria interna: " + e.getMessage();
            Log.e("Ficheros", texto);
            mostrarMensaje(texto);
        }
    }

    private void leerFicheroRaw(){
        try
        {
            String linea="";
            String cadena="";
            InputStream in =
                    getApplicationContext().getResources().openRawResource(R.raw.fichero_raw);

            // Otra forma
            // String filePath = "res/raw/fichero_raw";
            // InputStream in = this.getClass().getClassLoader().getResourceAsStream(filePath);

            BufferedReader brin =
                    new BufferedReader(new InputStreamReader(in));

            while((linea = brin.readLine())!=null){
                cadena += linea + "\n";
            }
            in.close();

            binding.cuadroTexto.setText(cadena);
        }
        catch (IOException e)
        {
            String texto = "Error al leer fichero del recurso raw: " + e.getMessage();
            Log.e("Ficheros", texto);
            mostrarMensaje(texto);
        }
    }

    private void mostrarMensaje(String texto) {
        Toast.makeText(this, texto, Toast.LENGTH_SHORT).show();
    }


}